#ifndef __MAVSDK_H__
#define __MAVSDK_H__

/*
 * 0. latitude (double, degrees)
 * 1. longitude (double, degrees)
 * 2. absolute altitude (double, meters)
 * 3. relative altitude (double, meters)
*/
#define POSITION_ARRAY_SIZE 4

#ifdef __cplusplus
extern "C" {
#endif
#include <stdint.h>
// Connexion management functions
int mavsdk_start(const char * url, const char * log_file, int timeout);
int mavsdk_stop(void);
int mavsdk_reboot(void);

// Flight state management functions
int mavsdk_arm(void);
int mavsdk_land(void);
int mavsdk_takeOff(void);
int mavsdk_takeOffAndWait(void);
int mavsdk_triggerParachute(void);

// Flight management functions
int mavsdk_loiter(float radius);
int mavsdk_setAirspeed(float airspeed);
int mavsdk_setAltitude(float altitude);
int mavsdk_setTargetCoordinates(double la, double lo, float a);
int mavsdk_setManualControlInput(void);

// Information functions
float mavsdk_getAltitude(void);
float mavsdk_getAltitudeRel(void);
float mavsdk_getInitialAltitude(void);
double mavsdk_getInitialLatitude(void);
double mavsdk_getInitialLongitude(void);
double mavsdk_getLatitude(void);
double mavsdk_getLongitude(void);
double *mavsdk_getPositionArray(void);
double mavsdk_getTakeOffAltitude(void);
float mavsdk_getYaw(void);
int mavsdk_healthAllOk(void);
bool mavsdk_isInManualMode(void);
int mavsdk_landed(void);
#ifdef __cplusplus
}
#endif

#endif /* __MAVSDK_H__ */
